ete2.parser.text_arraytable

Package ete2 :: Package parser :: Module text_arraytable |
[hide private]
[frames] | no frames]

# Module text_arraytable

source code

Functions | [hide private]
read_arraytable(matrix_file, mtype=`'``float``'`, arraytable_object=None) Reads a text tab-delimited matrix from file | source code
write_arraytable(A, fname, colnames=`[``]`) | source code

Variables | [hide private]
| __VERSION__ = ``'``ete2-2.0rev90``'``
| __package__ = ``'``ete2.parser``'``